@@ -18,7 +18,7 @@ func TestCreateDataFuncs(t *testing.T) {
 			fmap := CreateDataFuncs(ctx, nil)
 			actual := fmap["data"].(func() interface{})
 
-			assert.Same(t, ctx, actual().(*DataFuncs).ctx)
+			assert.Equal(t, ctx, actual().(*DataFuncs).ctx)
 		})
 	}
 }
